<template>
    <div class="card">
        <div class="card-header bg-info text-light">
            <div class="d-flex justify-content-between align-items-center">
                <h3 class="m-0">Products</h3>
                <div>
                    <router-link
                        :to="{
                            name: 'CreateProduct',
                        }"
                        class="btn btn-secondary btn-sm"
                        >Create Product</router-link
                    >
                    <router-link
                        :to="{
                            name: 'CreateOrder',
                        }"
                        class="btn btn-secondary btn-sm ms-2"
                        >Create Order</router-link
                    >
                </div>
            </div>
        </div>
        <div class="card-body ">
            <table class="table table-bordered table-hover rounded">
                <thead>
                    <tr>
                        <th class="bg-info text-light">#</th>
                        <th class="bg-info text-light">Name</th>
                        <th class="bg-info text-light">Arabic Name</th>
                        <th class="bg-info text-light">Price</th>
                        <th class="bg-info text-light">Stock</th>
                        <th class="bg-info text-light">Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <tr v-for="(product, key) in products" v-bind:key="key">
                        <td>{{ key + 1 }}</td>
                        <td>{{ product.name }}</td>
                        <td>{{ product.arabic_name }}</td>
                        <td>{{ product.price }}</td>
                        <td>{{ product.stock }}</td>
                        <td>
                            <router-link
                                :to="{
                                    name: 'EditProduct',
                                    params: { id: product.id },
                                }"
                                class="btn btn-secondary btn-sm"
                                >Edit</router-link
                            >
                            <button
                                type="button"
                                class="btn btn-danger ms-2 btn-sm"
                                v-on:click="deleteProduct(product.id)"
                            >
                                Delete
                            </button>
                        </td>
                    </tr>
                </tbody>
            </table>
        </div>
    </div>
</template>

<script>
import axios from "../../config/axios.js";
import toastr from "toastr";
export default {
    name: "ProductsList",
    data() {
        return {
            products: [], // Initial state
        };
    },
    mounted() {
        this.getProducts();
    },
    methods: {
        async getProducts() {
            let res = await axios.get("/api/products");
            this.products = res.data.products;
        },
        async deleteProduct(id) {
            let res = await axios.get(`/api/products/delete/${id}`);
            toastr.success(res.data.message);
            this.getProducts();
        },
    },
};
</script>
